@@ -1,7 +1,7 @@
 import gi
 import os
 import sys
-import typing
+import importlib.util
 from importlib.machinery import PathFinder
 from pathlib import Path
 
@@ -12,17 +12,11 @@ del sys.modules["gi"]
 import gi
 
 
-if typing.TYPE_CHECKING:
-    # Stubs for type checking our overrides
-    def require_version(namespace: str, version: str) -> None:
-        pass
-
-
 class GstOverrideImport:
     def find_spec(self, fullname, path, target=None):
         if not fullname.startswith("gi.overrides"):
             return None
-        finder = PathFinder()
+        finder = importlib.machinery.PathFinder()
         # From find_spec the docs:
         # If name is for a submodule (contains a dot), the parent module is automatically imported.
         spec = finder.find_spec(
