@@ -48,6 +48,17 @@ python module to use with Gst 0.10"
     warnings.warn(warn_msg, RuntimeWarning)
 
 
+class Float(float):
+    '''
+    A wrapper to force conversion to G_TYPE_FLOAT instead of G_TYPE_DOUBLE when
+    used in e.g. Gst.ValueArray.
+    '''
+    __gtype__ = GObject.TYPE_FLOAT
+
+
+__all__.append('Float')
+
+
 # Ensuring that PyGObject loads the URIHandler interface
 # so we can force our own implementation soon enough (in gstmodule.c)
 class URIHandler(Gst.URIHandler):
@@ -129,13 +140,13 @@ class NotWritableQuery(Exception):
 __all__.append('NotWritableQuery')
 
 
-class Query(Gst.Query, MiniObject):
+class Query(MiniObject, Gst.Query):
     def get_structure(self):
-        return StructureWrapper(_gi_gst.query_get_structure(self), self,
-                                False)
+        s = _gi_gst.query_get_structure(self)
+        return s._set_parent(self) if s is not None else None
 
     def writable_structure(self):
-        return StructureWrapper(_gi_gst.query_writable_structure(self), self, True)
+        return StructureWrapper(_gi_gst.query_writable_structure(self)._set_parent(self))
 
 
 Query = override(Query)
@@ -149,13 +160,13 @@ class NotWritableEvent(Exception):
 __all__.append('NotWritableEvent')
 
 
-class Event(Gst.Event, MiniObject):
+class Event(MiniObject, Gst.Event):
     def get_structure(self):
-        return StructureWrapper(_gi_gst.event_get_structure(self), self,
-                                False)
+        s = _gi_gst.event_get_structure(self)
+        return s._set_parent(self) if s is not None else None
 
     def writable_structure(self):
-        return StructureWrapper(_gi_gst.event_writable_structure(self), self, True)
+        return StructureWrapper(_gi_gst.event_writable_structure(self)._set_parent(self))
 
 
 Event = override(Event)
@@ -169,13 +180,13 @@ class NotWritableContext(Exception):
 __all__.append('NotWritableContext')
 
 
-class Context(Gst.Context, MiniObject):
+class Context(MiniObject, Gst.Context):
     def get_structure(self):
-        return StructureWrapper(_gi_gst.context_get_structure(self), self,
-                                False)
+        s = _gi_gst.context_get_structure(self)
+        return s._set_parent(self) if s is not None else None
 
     def writable_structure(self):
-        return StructureWrapper(_gi_gst.context_writable_structure(self), self, True)
+        return StructureWrapper(_gi_gst.context_writable_structure(self)._set_parent(self))
 
 
 Context = override(Context)
@@ -196,7 +207,7 @@ class NotWritableStructure(Exception):
 __all__.append('NotWritableStructure')
 
 
-class Caps(Gst.Caps, MiniObject):
+class Caps(MiniObject, Gst.Caps):
 
     def __nonzero__(self):
         return not self.is_empty()
@@ -240,11 +251,11 @@ class Caps(Gst.Caps, MiniObject):
         return self.get_size()
 
     def get_structure(self, index):
-        return StructureWrapper(_gi_gst.caps_get_structure(self, index), self,
-                                False)
+        s = _gi_gst.caps_get_structure(self, index)
+        return s._set_parent(self) if s is not None else None
 
     def writable_structure(self, index):
-        return StructureWrapper(_gi_gst.caps_writable_structure(self, index), self, True)
+        return StructureWrapper(_gi_gst.caps_writable_structure(self, index)._set_parent(self))
 
 
 Caps = override(Caps)
@@ -466,6 +477,16 @@ class Structure(Gst.Structure):
     def __str__(self):
         return self.to_string()
 
+    def _set_parent(self, parent):
+        self.__parent__ = parent
+        return self
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, _type, _value, _tb):
+        self._set_parent(None)
+
 
 Structure = override(Structure)
 __all__.append('Structure')
@@ -704,9 +725,27 @@ __all__.append('FractionRange')
 
 
 class ValueArray(Gst.ValueArray):
-    def __init__(self, array):
+    def __init__(self, array=[]):
         self.array = list(array)
 
+    def append(self, item):
+        self.array.append(item)
+
+    def prepend(self, item):
+        self.array = [item] + self.array
+
+    @staticmethod
+    def append_value(this, item):
+        this.append(item)
+
+    @staticmethod
+    def prepend_value(this, item):
+        this.prepend(item)
+
+    @staticmethod
+    def get_size(this):
+        return len(this.array)
+
     def __getitem__(self, index):
         return self.array[index]
 
@@ -728,9 +767,27 @@ __all__.append('ValueArray')
 
 
 class ValueList(Gst.ValueList):
-    def __init__(self, array):
+    def __init__(self, array=[]):
         self.array = list(array)
 
+    def append(self, item):
+        self.array.append(item)
+
+    def prepend(self, item):
+        self.array = [item] + self.array
+
+    @staticmethod
+    def append_value(this, item):
+        this.append(item)
+
+    @staticmethod
+    def prepend_value(this, item):
+        this.prepend(item)
+
+    @staticmethod
+    def get_size(this):
+        return len(this.array)
+
     def __getitem__(self, index):
         return self.array[index]
 
@@ -804,16 +861,16 @@ def pairwise(iterable):
 
 
 class StructureWrapper:
-    def __init__(self, structure, parent, writable):
+    """A Gst.Structure wrapper to force usage of a context manager.
+    """
+    def __init__(self, structure):
         self.__structure = structure
-        self.__parent__ = parent
 
     def __enter__(self):
         return self.__structure
 
     def __exit__(self, _type, _value, _tb):
-        self.__parent__ = False
-        return
+        self.__structure._set_parent(None)
 
 
 class MapInfo:
@@ -846,7 +903,7 @@ class MapInfo:
 __all__.append("MapInfo")
 
 
-class Buffer(Gst.Buffer, MiniObject):
+class Buffer(MiniObject, Gst.Buffer):
     @property
     def flags(self):
         return _gi_gst.mini_object_flags(self)
@@ -1031,6 +1088,10 @@ def init(argv=None):
     if Gst.is_initialized():
         return True
 
+    # FIXME: Workaround for pygobject handling nullability wrong
+    if argv is None:
+        argv = []
+
     return real_init(argv)
 
 
